/*******************************************************************************
* File Name: InputCounterClock.h
* Version 1.70
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_CLOCK_InputCounterClock_H)
#define CY_CLOCK_InputCounterClock_H

#include <cytypes.h>
#include <cyfitter.h>

/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v1_70 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */

/***************************************
*        Function Prototypes
***************************************/

void InputCounterClock_Start(void) ;
void InputCounterClock_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void InputCounterClock_StopBlock(void) ;
#endif

void InputCounterClock_StandbyPower(uint8 state) ;
void InputCounterClock_SetDividerRegister(uint16 clkDivider, uint8 reset) ;
uint16 InputCounterClock_GetDividerRegister(void) ;
void InputCounterClock_SetModeRegister(uint8 modeBitMask) ;
void InputCounterClock_ClearModeRegister(uint8 modeBitMask) ;
uint8 InputCounterClock_GetModeRegister(void) ;
void InputCounterClock_SetSourceRegister(uint8 clkSource) ;
uint8 InputCounterClock_GetSourceRegister(void) ;
#if defined(InputCounterClock__CFG3)
void InputCounterClock_SetPhaseRegister(uint8 clkPhase) ;
uint8 InputCounterClock_GetPhaseRegister(void) ;
#endif

#define InputCounterClock_Enable()                       InputCounterClock_Start()
#define InputCounterClock_Disable()                      InputCounterClock_Stop()
#define InputCounterClock_SetDivider(clkDivider)         InputCounterClock_SetDividerRegister(clkDivider, 1)
#define InputCounterClock_SetDividerValue(clkDivider)    InputCounterClock_SetDividerRegister((clkDivider) - 1, 1)
#define InputCounterClock_SetMode(clkMode)               InputCounterClock_SetModeRegister(clkMode)
#define InputCounterClock_SetSource(clkSource)           InputCounterClock_SetSourceRegister(clkSource)
#if defined(InputCounterClock__CFG3)
#define InputCounterClock_SetPhase(clkPhase)             InputCounterClock_SetPhaseRegister(clkPhase)
#define InputCounterClock_SetPhaseValue(clkPhase)        InputCounterClock_SetPhaseRegister((clkPhase) + 1)
#endif


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define InputCounterClock_CLKEN              (* (reg8 *) InputCounterClock__PM_ACT_CFG)
#define InputCounterClock_CLKEN_PTR          ((reg8 *) InputCounterClock__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define InputCounterClock_CLKSTBY            (* (reg8 *) InputCounterClock__PM_STBY_CFG)
#define InputCounterClock_CLKSTBY_PTR        ((reg8 *) InputCounterClock__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define InputCounterClock_DIV_LSB            (* (reg8 *) InputCounterClock__CFG0)
#define InputCounterClock_DIV_LSB_PTR        ((reg8 *) InputCounterClock__CFG0)
#define InputCounterClock_DIV_PTR            ((reg16 *) InputCounterClock__CFG0)

/* Clock MSB divider configuration register. */
#define InputCounterClock_DIV_MSB            (* (reg8 *) InputCounterClock__CFG1)
#define InputCounterClock_DIV_MSB_PTR        ((reg8 *) InputCounterClock__CFG1)

/* Mode and source configuration register */
#define InputCounterClock_MOD_SRC            (* (reg8 *) InputCounterClock__CFG2)
#define InputCounterClock_MOD_SRC_PTR        ((reg8 *) InputCounterClock__CFG2)

#if defined(InputCounterClock__CFG3)
/* Analog clock phase configuration register */
#define InputCounterClock_PHASE              (* (reg8 *) InputCounterClock__CFG3)
#define InputCounterClock_PHASE_PTR          ((reg8 *) InputCounterClock__CFG3)
#endif


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define InputCounterClock_CLKEN_MASK         InputCounterClock__PM_ACT_MSK
#define InputCounterClock_CLKSTBY_MASK       InputCounterClock__PM_STBY_MSK

/* CFG2 field masks */
#define InputCounterClock_SRC_SEL_MSK        InputCounterClock__CFG2_SRC_SEL_MASK
#define InputCounterClock_MODE_MASK          (~(InputCounterClock_SRC_SEL_MSK))

#if defined(InputCounterClock__CFG3)
/* CFG3 phase mask */
#define InputCounterClock_PHASE_MASK         InputCounterClock__CFG3_PHASE_DLY_MASK
#endif

#endif /* CY_CLOCK_InputCounterClock_H */


/* [] END OF FILE */
