/*******************************************************************************
* File Name: RefClock.h
* Version 1.70
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_CLOCK_RefClock_H)
#define CY_CLOCK_RefClock_H

#include <cytypes.h>
#include <cyfitter.h>

/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v1_70 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */

/***************************************
*        Function Prototypes
***************************************/

void RefClock_Start(void) ;
void RefClock_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void RefClock_StopBlock(void) ;
#endif

void RefClock_StandbyPower(uint8 state) ;
void RefClock_SetDividerRegister(uint16 clkDivider, uint8 reset) ;
uint16 RefClock_GetDividerRegister(void) ;
void RefClock_SetModeRegister(uint8 modeBitMask) ;
void RefClock_ClearModeRegister(uint8 modeBitMask) ;
uint8 RefClock_GetModeRegister(void) ;
void RefClock_SetSourceRegister(uint8 clkSource) ;
uint8 RefClock_GetSourceRegister(void) ;
#if defined(RefClock__CFG3)
void RefClock_SetPhaseRegister(uint8 clkPhase) ;
uint8 RefClock_GetPhaseRegister(void) ;
#endif

#define RefClock_Enable()                       RefClock_Start()
#define RefClock_Disable()                      RefClock_Stop()
#define RefClock_SetDivider(clkDivider)         RefClock_SetDividerRegister(clkDivider, 1)
#define RefClock_SetDividerValue(clkDivider)    RefClock_SetDividerRegister((clkDivider) - 1, 1)
#define RefClock_SetMode(clkMode)               RefClock_SetModeRegister(clkMode)
#define RefClock_SetSource(clkSource)           RefClock_SetSourceRegister(clkSource)
#if defined(RefClock__CFG3)
#define RefClock_SetPhase(clkPhase)             RefClock_SetPhaseRegister(clkPhase)
#define RefClock_SetPhaseValue(clkPhase)        RefClock_SetPhaseRegister((clkPhase) + 1)
#endif


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define RefClock_CLKEN              (* (reg8 *) RefClock__PM_ACT_CFG)
#define RefClock_CLKEN_PTR          ((reg8 *) RefClock__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define RefClock_CLKSTBY            (* (reg8 *) RefClock__PM_STBY_CFG)
#define RefClock_CLKSTBY_PTR        ((reg8 *) RefClock__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define RefClock_DIV_LSB            (* (reg8 *) RefClock__CFG0)
#define RefClock_DIV_LSB_PTR        ((reg8 *) RefClock__CFG0)
#define RefClock_DIV_PTR            ((reg16 *) RefClock__CFG0)

/* Clock MSB divider configuration register. */
#define RefClock_DIV_MSB            (* (reg8 *) RefClock__CFG1)
#define RefClock_DIV_MSB_PTR        ((reg8 *) RefClock__CFG1)

/* Mode and source configuration register */
#define RefClock_MOD_SRC            (* (reg8 *) RefClock__CFG2)
#define RefClock_MOD_SRC_PTR        ((reg8 *) RefClock__CFG2)

#if defined(RefClock__CFG3)
/* Analog clock phase configuration register */
#define RefClock_PHASE              (* (reg8 *) RefClock__CFG3)
#define RefClock_PHASE_PTR          ((reg8 *) RefClock__CFG3)
#endif


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define RefClock_CLKEN_MASK         RefClock__PM_ACT_MSK
#define RefClock_CLKSTBY_MASK       RefClock__PM_STBY_MSK

/* CFG2 field masks */
#define RefClock_SRC_SEL_MSK        RefClock__CFG2_SRC_SEL_MASK
#define RefClock_MODE_MASK          (~(RefClock_SRC_SEL_MSK))

#if defined(RefClock__CFG3)
/* CFG3 phase mask */
#define RefClock_PHASE_MASK         RefClock__CFG3_PHASE_DLY_MASK
#endif

#endif /* CY_CLOCK_RefClock_H */


/* [] END OF FILE */
