/*******************************************************************************
* File Name: TestClock.h
* Version 1.70
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_CLOCK_TestClock_H)
#define CY_CLOCK_TestClock_H

#include <cytypes.h>
#include <cyfitter.h>

/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v1_70 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */

/***************************************
*        Function Prototypes
***************************************/

void TestClock_Start(void) ;
void TestClock_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void TestClock_StopBlock(void) ;
#endif

void TestClock_StandbyPower(uint8 state) ;
void TestClock_SetDividerRegister(uint16 clkDivider, uint8 reset) ;
uint16 TestClock_GetDividerRegister(void) ;
void TestClock_SetModeRegister(uint8 modeBitMask) ;
void TestClock_ClearModeRegister(uint8 modeBitMask) ;
uint8 TestClock_GetModeRegister(void) ;
void TestClock_SetSourceRegister(uint8 clkSource) ;
uint8 TestClock_GetSourceRegister(void) ;
#if defined(TestClock__CFG3)
void TestClock_SetPhaseRegister(uint8 clkPhase) ;
uint8 TestClock_GetPhaseRegister(void) ;
#endif

#define TestClock_Enable()                       TestClock_Start()
#define TestClock_Disable()                      TestClock_Stop()
#define TestClock_SetDivider(clkDivider)         TestClock_SetDividerRegister(clkDivider, 1)
#define TestClock_SetDividerValue(clkDivider)    TestClock_SetDividerRegister((clkDivider) - 1, 1)
#define TestClock_SetMode(clkMode)               TestClock_SetModeRegister(clkMode)
#define TestClock_SetSource(clkSource)           TestClock_SetSourceRegister(clkSource)
#if defined(TestClock__CFG3)
#define TestClock_SetPhase(clkPhase)             TestClock_SetPhaseRegister(clkPhase)
#define TestClock_SetPhaseValue(clkPhase)        TestClock_SetPhaseRegister((clkPhase) + 1)
#endif


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define TestClock_CLKEN              (* (reg8 *) TestClock__PM_ACT_CFG)
#define TestClock_CLKEN_PTR          ((reg8 *) TestClock__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define TestClock_CLKSTBY            (* (reg8 *) TestClock__PM_STBY_CFG)
#define TestClock_CLKSTBY_PTR        ((reg8 *) TestClock__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define TestClock_DIV_LSB            (* (reg8 *) TestClock__CFG0)
#define TestClock_DIV_LSB_PTR        ((reg8 *) TestClock__CFG0)
#define TestClock_DIV_PTR            ((reg16 *) TestClock__CFG0)

/* Clock MSB divider configuration register. */
#define TestClock_DIV_MSB            (* (reg8 *) TestClock__CFG1)
#define TestClock_DIV_MSB_PTR        ((reg8 *) TestClock__CFG1)

/* Mode and source configuration register */
#define TestClock_MOD_SRC            (* (reg8 *) TestClock__CFG2)
#define TestClock_MOD_SRC_PTR        ((reg8 *) TestClock__CFG2)

#if defined(TestClock__CFG3)
/* Analog clock phase configuration register */
#define TestClock_PHASE              (* (reg8 *) TestClock__CFG3)
#define TestClock_PHASE_PTR          ((reg8 *) TestClock__CFG3)
#endif


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define TestClock_CLKEN_MASK         TestClock__PM_ACT_MSK
#define TestClock_CLKSTBY_MASK       TestClock__PM_STBY_MSK

/* CFG2 field masks */
#define TestClock_SRC_SEL_MSK        TestClock__CFG2_SRC_SEL_MASK
#define TestClock_MODE_MASK          (~(TestClock_SRC_SEL_MSK))

#if defined(TestClock__CFG3)
/* CFG3 phase mask */
#define TestClock_PHASE_MASK         TestClock__CFG3_PHASE_DLY_MASK
#endif

#endif /* CY_CLOCK_TestClock_H */


/* [] END OF FILE */
